@@ -1,5 +1,5 @@
 ## File Name: summary.msq.itemfit.R
-## File Version: 9.19
+## File Version: 9.25
 
 #**** summary for msq.itemfit
 summary.msq.itemfit <- function( object, file=NULL,  ... )
@@ -7,7 +7,8 @@ summary.msq.itemfit <- function( object, file=NULL,  ... )
 
     tam_osink( file=file)
 
-    cat("------------------------------------------------------------\n")
+    sdisplay <- tam_summary_display()
+    cat(sdisplay)
 
     #- package and R session
     tam_print_package_rsession(pack="TAM")
@@ -19,12 +20,14 @@ summary.msq.itemfit <- function( object, file=NULL,  ... )
     #--- print call
     tam_print_call(object$CALL)
 
-    cat("****************************************************\n")
+    sdisplay2 <- tam_summary_display("*", 52)
+    cat(sdisplay2)
     cat("\nSummary outfit and infit statistic\n")
     obji <- object$summary_itemfit
     tam_round_data_frame_print(obji=obji, from=2, digits=3, rownames_null=TRUE)
+    cat("\n")
 
-    cat("\n****************************************************\n")
+    cat(sdisplay2)
     cat("\nOutfit and infit statistic\n")
     obji <- object$itemfit
     ind <- grep( "fitgroup", colnames(obji) )
