@@ -1,10 +1,10 @@
 ## File Name: summary.tam.R
-## File Version: 9.52
+## File Version: 9.582
 
 #****** summary for tam object
 summary.tam <- function( object, file=NULL, ...)
 {
-    tam_osink( file=file)
+    tam_osink(file=file)
 
     latreg <- FALSE
     if ( class(object)=="tam.latreg" ){
@@ -12,7 +12,8 @@ summary.tam <- function( object, file=NULL, ...)
         object$irtmodel <- "tam.latreg"
     }
 
-    cat("------------------------------------------------------------\n")
+    sdisplay <- tam_summary_display()
+    cat(sdisplay)
 
     #--- package and R session
     tam_print_package_rsession(pack="TAM")
@@ -21,13 +22,13 @@ summary.tam <- function( object, file=NULL, ...)
 
     cat("Multidimensional Item Response Model in TAM \n\n")
     irtmodel <- object$irtmodel
-    cat("IRT Model", irtmodel )
+    cat("IRT Model:", irtmodel )
 
     #--- print call
     tam_print_call(object$CALL)
 
-    cat("------------------------------------------------------------\n")
-    cat( "Number of iterations=", object$iter, "\n" )
+    cat(sdisplay)
+    cat( "Number of iterations", "=", object$iter, "\n" )
 
     ctr <- object$control
     if (ctr$snodes==0){
@@ -42,37 +43,41 @@ summary.tam <- function( object, file=NULL, ...)
         }
     }
 
-    cat( "\nDeviance=", round( object$deviance, 2 ), "\n" )
-    cat( "   Log likelihood=", round( object$ic$loglike, 2 ), "\n" )
+    digits_ll <- 2    # digits after decimal for log-likelihood
+    cat( "\nDeviance", "=", round( object$deviance, digits_ll ), "\n" )
+    cat( "Log likelihood", "=", round( object$ic$loglike, digits_ll ), "\n" )
     # cat( "   Log prior=", round( object$ic$logprior, 2 ), "\n" )
     # cat( "   Log posterior=", round( object$ic$logpost, 2 ), "\n\n" )
 
-    cat( "Number of persons=", object$nstud, "\n" )
-    cat( "Number of persons used=", object$ic$n, "\n" )
+    cat( "Number of persons", "=", object$nstud, "\n" )
+    cat( "Number of persons used", "=", object$ic$n, "\n" )
 
-    if( ! is.null( object$formulaA)  ){
-        cat( "Number of generalized items=", object$nitems, "\n" )
-        cat( "Number of items=", ncol(object$resp_orig), "\n" )
-    } else {
-        cat( "Number of items=", object$nitems, "\n" )
+    if (!latreg){
+        if( ! is.null( object$formulaA)  ){
+            cat( "Number of generalized items", "=", object$nitems, "\n" )
+            cat( "Number of items", "=", ncol(object$resp_orig), "\n" )
+        } else {
+            cat( "Number of items", "=", object$nitems, "\n" )
+        }
     }
 
-    cat( "Number of estimated parameters=", object$ic$Npars, "\n" )
+    cat( "Number of estimated parameters", "=", object$ic$Npars, "\n" )
     if (! latreg ){
-        cat( "    Item threshold parameters=", object$ic$Nparsxsi, "\n" )
-        cat( "    Item slope parameters  =", object$ic$NparsB, "\n" )
+        cat( "    Item threshold parameters", "=", object$ic$Nparsxsi, "\n" )
+        cat( "    Item slope parameters", "=", object$ic$NparsB, "\n" )
     }
-    cat( "    Regression parameters  =", object$ic$Nparsbeta, "\n" )
-    cat( "    (Co)Variance parameters=", object$ic$Nparscov, "\n\n" )
+    cat( "    Regression parameters", "=", object$ic$Nparsbeta, "\n" )
+    cat( "    Variance/covariance parameters", "=", object$ic$Nparscov, "\n\n" )
 
     #--- print information criteria
-    res <- tam_summary_print_ic( object=object )
+    res <- tam_summary_print_ic( object=object, digits_values=digits_ll )
 
-    cat("------------------------------------------------------------\n")
+    cat(sdisplay)
     cat("EAP Reliability\n")
     obji <- round( object$EAP.rel, 3 )
-    print( obji )
-    cat("------------------------------------------------------------\n")
+    print(obji)
+
+    cat(sdisplay)
     cat("Covariances and Variances\n")
     if ( object$G >1){
         a1 <- stats::aggregate( object$variance, list( object$group ), mean )
@@ -82,21 +87,22 @@ summary.tam <- function( object, file=NULL, ...)
     if ( object$G >1){
         names(obji) <- paste0("Group", object$groups )
     }
-    print( obji )
-    cat("------------------------------------------------------------\n")
+    print(obji)
+
+    cat(sdisplay)
     cat("Correlations and Standard Deviations (in the diagonal)\n")
     if ( object$G >1){
-        obji <- sqrt( object$variance )
+        obji <- sqrt(object$variance)
     } else {
         obji <- stats::cov2cor(object$variance)
-        diag(obji) <- sqrt( diag( object$variance) )
+        diag(obji) <- sqrt( diag(object$variance) )
     }
     if ( object$G >1){
         names(obji) <- paste0("Group", object$groups )
     }
     tam_round_data_frame_print(obji=obji, digits=3)
 
-    cat("------------------------------------------------------------\n")
+    cat(sdisplay)
     cat("Regression Coefficients\n")
     tam_round_data_frame_print(obji=object$beta, digits=5)
 
@@ -104,7 +110,7 @@ summary.tam <- function( object, file=NULL, ...)
     summary_tam_print_latreg_stand(object=object, digits_stand=4)
 
     if ( ! latreg ){
-        cat("------------------------------------------------------------\n")
+        cat(sdisplay)
         cat("Item Parameters -A*Xsi\n")
         obji <- object$item
         tam_round_data_frame_print(obji=obji, from=2, to=ncol(obji), digits=3, rownames_null=FALSE)
@@ -132,14 +138,14 @@ summary.tam <- function( object, file=NULL, ...)
         #*******************
         # output efa
         if ( object$irtmodel %in% c("efa") ){
-            cat("------------------------------------------------------------\n")
+            cat(sdisplay)
             cat("\nStandardized Factor Loadings Oblimin Rotation\n")
             print(object$efa.oblimin)
         }
         #*******************
         # output bifactor models
         if ( object$irtmodel %in% c("bifactor1", "bifactor2","efa") ){
-            cat("------------------------------------------------------------\n")
+            cat(sdisplay)
             if (irtmodel=="efa"){
                 cat("\nStandardized Factor Loadings (Schmid Leimann transformation)\n")
                 obji <- object$B.SL
@@ -150,18 +156,18 @@ summary.tam <- function( object, file=NULL, ...)
             tam_round_data_frame_print(obji=obji, digits=3)
             meas <- object$meas
             cat("\nDimensionality/Reliability Statistics\n\n")
-            cat("ECV=", round( meas["ECV"],3 ), "\n")
-            cat("Omega Asymptotical=", round( meas["omega_a"],3 ), "\n")
-            cat("Omega Total=", round( meas["omega_t"],3 ), "\n")
-            cat("Omega Hierarchical=", round( meas["omega_h"],3 ), "\n")
+            cat("ECV", "=", round( meas["ECV"],3), "\n")
+            cat("Omega Asymptotical", "=", round( meas["omega_a"],3), "\n")
+            cat("Omega Total", "=", round( meas["omega_t"],3 ), "\n")
+            cat("Omega Hierarchical", "=", round( meas["omega_h"],3), "\n")
             if (object$maxK==2){
-                cat("Omega Total (GY)=", round( meas["omega_tot_diff"],3 ), "\n")
+                cat("Omega Total (GY)", "=", round( meas["omega_tot_diff"],3), "\n")
                 cat( "  Omega Total GY (Green & Yang, 2009) includes item difficulties\n")
                 cat( "  and estimates the reliability of the sum score.\n")
             }
         }
     }
-    #******
+    #** close sink
     tam_csink(file=file)
 }
 #*******************************************************
