@@ -1,5 +1,5 @@
 ## File Name: tam_jml_version2.R
-## File Version: 9.43
+## File Version: 9.476
 
 ##################################################################
 ##################################################################
@@ -251,6 +251,7 @@ tam_jml_version2 <-
       rprobs <- res[["rprobs"]]
       crprobs <- t( matrix( aperm( rprobs, c(2,1,3) ), nrow=dim(rprobs)[3], byrow=TRUE ) )
       crprobs <- crprobs[, match( theta, theta.unique) ]
+
       #    cr <- log(crprobs + 10^(-80)) * t(cResp)
       cr <- log(crprobs ) * t(cResp)
       deviance <- -2 * sum(cr, na.rm=TRUE)
@@ -305,6 +306,9 @@ tam_jml_version2 <-
         "se.xsi"=errorP
     )
 
+    #** response probabilities
+    rprobs <- rprobs[,, match( theta, theta.unique)]
+
     ############################################################
     s2 <- Sys.time()
     if (progress){
@@ -317,19 +321,19 @@ tam_jml_version2 <-
 
     # Output list
     deviance.history <- deviance.history[ 1:iter, ]
-    res <- list( "item"=item, "xsi"=xsi,  "errorP"=errorP,
-                 "theta"=theta[,1],"errorWLE"=errorWLE, "WLE"=thetaWLE,
-                 "WLEreliability"=WLEreliability,
-                 "PersonScores"=PersonScores, "ItemScore"=ItemScore,
-                 "PersonMax"=PersonMaxB, "ItemMax"=ItemMax,
-                 "deviance"=deviance, "deviance.history"=deviance.history,
-                 "resp"=resp, "resp.ind"=resp.ind, "group"=group,
-                 "pweights"=pweights, "A"=A, "B"=B,
-                 "nitems"=nitems, "maxK"=maxK,
-                 "nstud"=nstud, "resp.ind.list"=resp.ind.list,
-                 "xsi.fixed"=xsi.fixed, "deviance"=deviance,
-                 "deviance.history"=deviance.history,
-                 "control"=con1a, "iter"=iter)
+    res <- list( item=item, xsi=xsi,  errorP=errorP,
+                 theta=theta[,1],errorWLE=errorWLE, WLE=thetaWLE,
+                 WLEreliability=WLEreliability,
+                 PersonScores=PersonScores, ItemScore=ItemScore,
+                 PersonMax=PersonMaxB, ItemMax=ItemMax,
+                 deviance=deviance, deviance.history=deviance.history,
+                 resp=resp, resp.ind=resp.ind, group=group,
+                 pweights=pweights, A=A, B=B,
+                 nitems=nitems, maxK=maxK, rprobs=rprobs,
+                 nstud=nstud, resp.ind.list=resp.ind.list,
+                 xsi.fixed=xsi.fixed, deviance=deviance,
+                 deviance.history=deviance.history,
+                 control=con1a, iter=iter)
     res$time <-  c(s11,s2,s2-s11)
     class(res) <- "tam.jml"
     return(res)
