@@ -1,10 +1,11 @@
 ## File Name: tam_mml_calc_prob.R
-## File Version: 9.393
+## File Version: 9.403
 
 #####################################################################
 # calc_prob: Calculation of probabilities
 tam_mml_calc_prob <- function(iIndex, A, AXsi, B, xsi, theta,
-            nnodes, maxK, recalc=TRUE, use_rcpp=FALSE, maxcat=NULL)
+            nnodes, maxK, recalc=TRUE, use_rcpp=FALSE, maxcat=NULL,
+            avoid_outer=FALSE)
 {
     if (use_rcpp){
         if ( is.null(maxcat) ){ use_rcpp <- FALSE }
@@ -13,12 +14,12 @@ tam_mml_calc_prob <- function(iIndex, A, AXsi, B, xsi, theta,
     if ( ! use_rcpp ){
         #-- R function
         res <- tam_mml_calc_prob_R( iIndex=iIndex, A=A, AXsi=AXsi, B=B, xsi=xsi,
-                    theta=theta, nnodes=nnodes, maxK=maxK, recalc=recalc )
+                    theta=theta, nnodes=nnodes, maxK=maxK, recalc=recalc,
+                    avoid_outer=avoid_outer)
         rprobs <- res$rprobs
         AXsi <- res$AXsi
     } else {
         #-- Rcpp function
-
         res <- tam_rcpp_calc_prob( A=as.vector(A), dimA=dim(A), xsi=xsi,
                         maxcat=maxcat, AXsi0=AXsi, iIndex=iIndex, theta=theta, B=as.vector(B) )
         LI <- length(iIndex)
