@@ -1,11 +1,11 @@
 ## File Name: tam_mml_progress_em.R
-## File Version: 0.15
+## File Version: 0.17
 
 tam_mml_progress_em <- function(progress, deviance, deviance_change, iter,
         rel_deviance_change, xsi_change, beta_change, variance_change, B_change,
         is_latreg=FALSE, is_mml_3pl=FALSE, guess_change=0,
         skillspace="normal", delta_change=0, digits_pars=6, devch,
-        penalty_xsi=0 )
+        penalty_xsi=0, is_np=FALSE, np_change=NULL )
 {
     if (progress){
         disp_fct <- "Deviance"
@@ -30,6 +30,9 @@ tam_mml_progress_em <- function(progress, deviance, deviance_change, iter,
         if ( is_mml_3pl ){
             cat( "\n  Maximum item guessing parameter change:", round( guess_change, digits_pars ) )
         }
+        if ( is_np ){
+            cat( "\n  Maximum item parameter change:", round( np_change, digits_pars ) )
+        }
         #--- display distribution parameters
         if ( skillspace=="normal"){
             cat( "\n  Maximum regression parameter change:", round( beta_change, digits_pars ) )
