@@ -1,9 +1,10 @@
 ## File Name: tamaanify.proc.lavaanmodel.R
-## File Version: 9.06
+## File Version: 9.08
 
 ############################################################
 # process lavaan model
-tamaanify.proc.lavaanmodel <- function(res, resp ){
+tamaanify.proc.lavaanmodel <- function(res, resp )
+{
     tam1 <- res$tammodel.dfr
     ind1 <- which( paste(tam1$syn)=="LAVAANMODEL:" )
     index1 <- tam1$part_begin[ ind1 ]
@@ -14,5 +15,5 @@ tamaanify.proc.lavaanmodel <- function(res, resp ){
     lavres <- lavaanify.IRT( lavmodel=res$LAVAANMODEL, data=resp )
     res$lavpartable <- lavres$lavpartable
     return(res)
-        }
+}
 ##########################################################
